@@ -24,7 +24,7 @@ def parse_args(msg):
     parser.add_argument(
         "-u", "--user",
         type=str,
-        required=True,
+        required=False,
         help="Username to use when connecting",
         dest="username"
     )
@@ -35,6 +35,12 @@ def parse_args(msg):
         help="Password to use when connecting",
         dest="password"
     )
+    parser.add_argument(
+        "--token",
+        type=str,
+        required=False,
+        help="Specify the token for token-based authentication",
+    )
     parser.add_argument(
         "-c", "--path-cert",
         type=str,
@@ -93,7 +99,6 @@ def parse_args(msg):
         "--gnmi-path-target",
         type=str,
         required=False,
-        default="",
         help="Set target for GNMI path if it is different to the endpoint itself."
     )
     parser.add_argument(
@@ -130,21 +135,18 @@ def parse_args(msg):
         "--ext-history-range-start",
         type=str,
         required=False,
-        default="",
         help="Specify the start timestamp for the GNMI history range",
     )
     parser.add_argument(
         "--ext-history-range-end",
         type=str,
         required=False,
-        default="",
         help="Specify the end timestamp for the GNMI history range",
     )
     parser.add_argument(
         "--ext-history-snapshot-time",
         type=str,
         required=False,
-        default="",
         help="Specify the snapshit time for the GNMI history",
     )
 
@@ -169,7 +171,7 @@ def parse_args(msg):
         if len(args.gnmi_path) > 1:
             parser.error(f"Only one path supported when doing a {args.operation} operation")
 
-    if not args.password:
+    if not args.password and not args.token:
         args.password = getpass("Device password: ")
 
     return args
